@@ -237,11 +237,11 @@ void HotspotHelper::unloadStandardUSB(){
 
 int HotspotHelper::loadNokiaUSB(){
 	/* -1=fail, 0=ok */
-	qDebug("** Loading g_nokia **");
+	qDebug("** Loading g_file_storage **");
 	int ret;
-	ret = loadModule("g_nokia");
+	ret = loadModule("g_file_storage");
 	if(ret != 0){
-		qDebug("WARNING : Was not able to load g_nokia");
+		qDebug("WARNING : Was not able to load g_file_storage");
 		return -1;
 	}
 	return 0;
@@ -330,25 +330,23 @@ int HotspotHelper::prepareWifiInterface(MobileHotspotConfiguration &configuratio
 		qDebug("WARNING :  Was not able to disable the Wifi interface");
 
 	/** Power saving - May not work on adhoc, but who knows **/
-	if(configuration.disablePowerSaving){
-		/** Switch to managed mode (to be able to change power management) - may fail, not fatal unless timeout **/
-		ret = setAdhocMode(configuration, false);
-		if(ret == -2){
-			qDebug("Error (timeout) while enabling managed mode");
-			return -1;
-		}
-		else if(ret != 0)
-			qDebug("WARNING : Was not able to enable managed mode");
-
-		/** Disable power management - may fail, not fatal unless timeout **/
-		ret = setPowerManagement(configuration, false);
-		if(ret == -2){
-			qDebug("Error (timeout) while disabling power management");
-			return -1;
-		}
-		else if(ret != 0)
-			qDebug("WARNING : Was not able to disable power management");
+	/** Switch to managed mode (to be able to change power management) - may fail, not fatal unless timeout **/
+	ret = setAdhocMode(configuration, false);
+	if(ret == -2){
+		qDebug("Error (timeout) while enabling managed mode");
+		return -1;
 	}
+	else if(ret != 0)
+		qDebug("WARNING : Was not able to enable managed mode");
+
+	/** Disable power management - may fail, not fatal unless timeout **/
+	ret = setPowerManagement(configuration, false);
+	if(ret == -2){
+		qDebug("Error (timeout) while disabling power management");
+		return -1;
+	}
+	else if(ret != 0)
+		qDebug("WARNING : Was not able to disable power management");
 
 	/** Enable Ad-Hoc mode - may fail, not fatal unless timeout **/
 	ret = setAdhocMode(configuration, true);
@@ -674,9 +672,10 @@ int HotspotHelper::startDnsMasq(MobileHotspotConfiguration &configuration, QProc
 	/** Credits to Rambo for the basics of the command **/
 	qDebug("** Starting dnsmasq **");
 	QString cmd("/usr/sbin/dnsmasq");
+	cmd += " --no-daemon";
 	cmd += " -i "; cmd += configuration.lanInterface;
 	cmd += " -a "; cmd += configuration.lanNetwork + "1";
-	cmd += " -I lo -z -x "; cmd += dnsmasqPIDFile(configuration);
+	cmd += " -I lo -z";
 	cmd += " --dhcp-range="; cmd += configuration.lanNetwork + "10,"; cmd += configuration.lanNetwork + "200,6h";
 	cmd += " --dhcp-authoritative";
 	if(configuration.internetEnabled){
@@ -693,67 +692,11 @@ int HotspotHelper::startDnsMasq(MobileHotspotConfiguration &configuration, QProc
 	return 0;
 }
 
-QString HotspotHelper::dnsmasqPIDFile(MobileHotspotConfiguration &configuration){
-	QString res("/var/run/dnsmasq.");
-	res += configuration.lanInterface + ".pid";
-	return res;
-}
-
-int HotspotHelper::stopDnsMasq(MobileHotspotConfiguration &configuration){
-	/** -1=fail, -2=timeout, 0=ok **/
+int HotspotHelper::stopDnsMasq(MobileHotspotConfiguration &configuration, QProcess *dnsmasqProcess){
+	/** -1=fail, 0=ok **/
 	qDebug("** Stopping dnsmasq **");
-	QFile file(dnsmasqPIDFile(configuration));
-	int pid = -1, tries;
-	bool cmdret, trying;
-	int ret;
-	bool ret2 = file.exists();
-	if(ret2)
-		if(file.open(QIODevice::ReadOnly | QIODevice::Text)){
-			QTextStream stream(&file);
-			pid = stream.readLine().toInt(&ret2);
-			file.close();
-			if(! ret2){
-				qDebug("FAILURE : Cannot read the PID from the dnsmasq PID file");
-				return -1;
-			}
-			if(! file.remove()){
-				qDebug("FAILURE : Cannot delete the PID file of dnsmasq");
-				return -1;
-			}
-		}
-		else{
-			qDebug("FAILURE : Cannot open the dnsmasq PID file");
-			return -1;
-		}
-	else{
-		qDebug("FAILURE : dnsmasq PID file does not exist");
-		return -1;
-	}
-	QString cmd("kill -15 "); cmd += QString::number(pid);
-	cmdret = CommandHelper::executeCommand(cmd, &ret);
-	if( (! cmdret) || (cmdret && ret != 0) ){
-		qDebug("FAILURE : Cannot send SIGTERM to dnsmasq");
-		return -1;
-	}
-	tries = 0; trying = true;
-	cmd = "/bin/sh -c \"ps -Ac | grep -v grep | grep dnsmasq | grep ";
-	cmd += configuration.lanInterface + " | grep ";
-	cmd += QString::number(pid) + " | wc -l\"";
-	while(trying && tries < MAX_TRIES){
-		tries++;
-		QString res;
-		CommandHelper::executeCommandWithStdOut(cmd, &ret, &res);
-		res = res.left(res.size() - 1); // the last \n added at stdout is removed
-		if(res == "0")
-			trying = false;
-		else
-			CommandHelper::executeCommand("sleep 1");
-	}
-	if(trying){
-		qDebug("FAILURE : System was too slow stopping dnsmasq");
-		return -2;
-	}
-	return 0;
+	dnsmasqProcess->terminate();
+	return dnsmasqProcess->waitForFinished(MAX_TRIES * 1000) ? 0 : -1;
 }
 
 int HotspotHelper::setIPTables(MobileHotspotConfiguration &configuration, int *ipforward){
@@ -813,10 +756,10 @@ int HotspotHelper::unsetIPTables(MobileHotspotConfiguration &configuration, int
 		result = -1;
 	}
 	cmdret = CommandHelper::executeCommand("/usr/sbin/iptables -F");
-	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -X");
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -t nat -F");
-	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -t nat -X");
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -t mangle -F");
+	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -X");
+	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -t nat -X");
 	cmdret = cmdret && CommandHelper::executeCommand("/usr/sbin/iptables -t mangle -X");
 	if(! cmdret){
 		qDebug("FAILURE : Cannot flush iptables");
