@@ -31,11 +31,11 @@ void InternetAccessGUI::setConfiguration(MobileHotspotConfiguration &configurati
 		if(configuration.internetAPID == apns.at(i).at(1) && configuration.internetAPType == apns.at(i).at(2))
 			configIndex = i;
 	}
-	if(configuration.enforcement2g3g == IGNORE)
+	if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_IGNORE)
 		ui.lst2G3G->setCurrentIndex(0);
-	else if(configuration.enforcement2g3g == ENFORCE_2G)
+	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G)
 		ui.lst2G3G->setCurrentIndex(1);
-	else if(configuration.enforcement2g3g == ENFORCE_3G)
+	else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G)
 		ui.lst2G3G->setCurrentIndex(2);
 	else
 		ui.lst2G3G->setCurrentIndex(3);
@@ -45,19 +45,21 @@ void InternetAccessGUI::setConfiguration(MobileHotspotConfiguration &configurati
 }
 
 void InternetAccessGUI::configuration(MobileHotspotConfiguration *configuration){
-	configuration->internetAPName = ui.lstAPN->itemText(ui.lstAPN->currentIndex()).split("     ").at(0);
-	configuration->internetAPType = ui.lstAPN->itemText(ui.lstAPN->currentIndex()).split("     ").at(1);
-	configuration->internetAPID = ui.lstAPN->itemData(ui.lstAPN->currentIndex()).toString();
+	if(ui.lstAPN->count() > 0){
+		configuration->internetAPName = ui.lstAPN->itemText(ui.lstAPN->currentIndex()).split("     ").at(0);
+		configuration->internetAPType = ui.lstAPN->itemText(ui.lstAPN->currentIndex()).split("     ").at(1);
+		configuration->internetAPID = ui.lstAPN->itemData(ui.lstAPN->currentIndex()).toString();
+	}
 	configuration->lanNetwork = validNetwork();
 	configuration->internetEnabled = ui.chkInternet->isChecked();
 	if(ui.lst2G3G->currentIndex() == 0)
-		configuration->enforcement2g3g = IGNORE;
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_IGNORE;
 	else if(ui.lst2G3G->currentIndex() == 1)
-		configuration->enforcement2g3g = ENFORCE_2G;
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_2G;
 	else if(ui.lst2G3G->currentIndex() == 2)
-		configuration->enforcement2g3g = ENFORCE_3G;
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_3G;
 	else
-		configuration->enforcement2g3g = ENFORCE_2G3G;
+		configuration->enforcement2g3g = ENFORCEMENT_2G3G_DOUBLE;
 }
 
 QString InternetAccessGUI::validNetwork(){
