@@ -38,10 +38,6 @@ void MobileHotspotConfiguration::load(){
 	encryptionKey = item->value("0000000000000").toString();
 	delete item;
 
-	item = new GConfItem(GCONF_POWER);
-	disablePowerSaving = item->value("false").toString() == "true";
-	delete item;
-
 	item = new GConfItem(GCONF_INTERFACE);
 	lanInterface = item->value(INTERFACE_WLAN).toString();
 	delete item;
@@ -69,33 +65,18 @@ void MobileHotspotConfiguration::load(){
 	item = new GConfItem(GCONF_2G3G);
 	QString enf = item->value("ignore").toString();
 	if(enf == "2g")
-		enforcement2g3g = ENFORCE_2G;
+		enforcement2g3g = ENFORCEMENT_2G3G_2G;
 	else if(enf == "3g")
-		enforcement2g3g = ENFORCE_3G;
+		enforcement2g3g = ENFORCEMENT_2G3G_3G;
 	else if(enf == "2g3g")
-		enforcement2g3g = ENFORCE_2G3G;
+		enforcement2g3g = ENFORCEMENT_2G3G_DOUBLE;
 	else
-		enforcement2g3g = IGNORE;
+		enforcement2g3g = ENFORCEMENT_2G3G_IGNORE;
 	delete item;
 
 	loadUSBMAC();
 }
 
-QString MobileHotspotConfiguration::newMAC(){
-	QString result("02:");
-	qsrand(QDateTime::currentDateTime().toTime_t());
-	for(int i = 0; i < 5; i++){
-		if(i > 0)
-			result += ":";
-		int number1 = qrand() % 16;
-		int number2 = qrand() % 16;
-		result += QString("%1").arg(number1, 0, 16);
-		result += QString("%1").arg(number2, 0, 16);
-	}
-	result = result.toLower();
-	return result;
-}
-
 void MobileHotspotConfiguration::save(){
 	GConfItem *item;
 
@@ -111,10 +92,6 @@ void MobileHotspotConfiguration::save(){
 	item->set(encryptionKey);
 	delete item;
 
-	item = new GConfItem(GCONF_POWER);
-	item->set(disablePowerSaving ? "true" : "false");
-	delete item;
-
 	item = new GConfItem(GCONF_INTERFACE);
 	item->set(lanInterface);
 	delete item;
@@ -140,11 +117,11 @@ void MobileHotspotConfiguration::save(){
 	delete item;
 
 	item = new GConfItem(GCONF_2G3G);
-	if(enforcement2g3g == ENFORCE_2G)
+	if(enforcement2g3g == ENFORCEMENT_2G3G_2G)
 		item->set("2g");
-	else if(enforcement2g3g == ENFORCE_3G)
+	else if(enforcement2g3g == ENFORCEMENT_2G3G_3G)
 		item->set("3g");
-	else if(enforcement2g3g == ENFORCE_2G3G)
+	else if(enforcement2g3g == ENFORCEMENT_2G3G_DOUBLE)
 		item->set("2g3g");
 	else
 		item->set("ignore");
@@ -175,6 +152,21 @@ void MobileHotspotConfiguration::loadUSBMAC(){
 	}
 }
 
+QString MobileHotspotConfiguration::newMAC(){
+	QString result("02:");
+	qsrand(QDateTime::currentDateTime().toTime_t());
+	for(int i = 0; i < 5; i++){
+		if(i > 0)
+			result += ":";
+		int number1 = qrand() % 16;
+		int number2 = qrand() % 16;
+		result += QString("%1").arg(number1, 0, 16);
+		result += QString("%1").arg(number2, 0, 16);
+	}
+	result = result.toLower();
+	return result;
+}
+
 void MobileHotspotConfiguration::saveUSBMAC(){
 	QFile file(FILE_USBMAC);
 	try{
