@@ -10,7 +10,6 @@
 #define GCONF_APNAME GCONF "/name"
 #define GCONF_ENCRYPTION GCONF "/encryption"
 #define GCONF_KEY GCONF "/key"
-#define GCONF_POWER GCONF "/power"
 #define GCONF_INTERFACE GCONF "/interface"
 #define GCONF_APN GCONF "/apn"
 #define GCONF_APID GCONF "/apid"
@@ -18,14 +17,15 @@
 #define GCONF_NETWORK GCONF "/network"
 #define GCONF_INTERNET GCONF "/internet"
 #define GCONF_2G3G	GCONF "/2g3g"
-#define FILE_USBMAC "/home/user/.qtmobilehotspot/usb.mac"
+#define PERSISTENT_FOLDER "/home/user/.qtmobilehotspot"
+#define FILE_USBMAC PERSISTENT_FOLDER "/usb.mac"
 
 
-enum Enforcement{
-	ENFORCE_2G,
-	ENFORCE_3G,
-	ENFORCE_2G3G,
-	IGNORE
+enum Enforcement_2G3G{
+	ENFORCEMENT_2G3G_2G,
+	ENFORCEMENT_2G3G_3G,
+	ENFORCEMENT_2G3G_DOUBLE,
+	ENFORCEMENT_2G3G_IGNORE
 };
 
 
@@ -41,8 +41,8 @@ public:
 	static const QString INTERFACE_GPRS;
 
 	QString hotspotName, encryptionType, encryptionKey, lanInterface, lanNetwork, internetAPName, internetAPType, internetAPID, usbMAC;
-	bool internetEnabled, disablePowerSaving;
-	Enforcement enforcement2g3g;
+	bool internetEnabled;
+	Enforcement_2G3G enforcement2g3g;
 
 public:
 	MobileHotspotConfiguration(QObject *parent = 0);
