@@ -30,6 +30,7 @@
 MobileHotspotGUI::MobileHotspotGUI(QWidget *parent)
     : QMainWindow(parent)
 {
+	dnsmasqProcess = 0;
 	loadPlugins();
 	sortPlugins();
 	ui.setupUi(this);
@@ -142,17 +143,15 @@ void MobileHotspotGUI::updateDisplayedConfiguration(){
 	ui.lstAccessPoint->clear();
 	ui.lstAccessPoint->addItem(configuration.hotspotName);
 	ui.lstAccessPoint->addItem(configuration.encryptionType == configuration.ENCRYPTION_WEP ? tr("WEP") : tr("No encryption"));
-	if(configuration.disablePowerSaving)
-		ui.lstAccessPoint->addItem(tr("Disable power-saving"));
 
 	ui.lstInternetAccess->clear();
 	QString s = configuration.internetAPName;
 	if(s != "" && configuration.internetInterface() == configuration.INTERFACE_GPRS){
-		if(configuration.enforcement2g3g != IGNORE){
+		if(configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE){
 			s += " (";
-			if(configuration.enforcement2g3g == ENFORCE_2G)
+			if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G)
 				s += tr("2G");
-			else if(configuration.enforcement2g3g == ENFORCE_3G)
+			else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G)
 				s += tr("3G");
 			else
 				s += tr("2G/3G");
@@ -325,11 +324,11 @@ void MobileHotspotGUI::configureInterface(int index){
 void MobileHotspotGUI::start(bool notification){
 	int ret;
 	/** Find previous enforcement **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE){
 		ret = DBUSHelper::internetEnforcement2G3G(&previousEnforcement);
 		if(ret != 0){
-			qDebug("WARNING : Cannot get the current level of 2G/3G enforcement, using default value");
-			previousEnforcement = ENFORCEMENT_NONE;
+			qDebug("WARNING : Cannot get the current level of 2G/3G enforcement, using default value DOUBLE");
+			previousEnforcement = DBUS_2G3G_DOUBLE;
 		}
 	}
 
@@ -363,9 +362,8 @@ void MobileHotspotGUI::startProcedure(){
 		return;
 	}
 
-	/** Save scan interval & powersave (if there is one) **/
+	/** Save scan interval **/
 	scanInterval = APNHelper::scanInterval();
-	apnPowerSave = APNHelper::apnPowerSave(configuration.internetAPID);
 
 	/** Notify plugins **/
 	QListIterator<QString> pluginsIterator = QListIterator<QString>(sortedPlugins);
@@ -386,10 +384,10 @@ void MobileHotspotGUI::startProcedure(){
 
 		/** Internet connection handling **/
 		if(configuration.internetEnabled){
-
+			qDebug("Previous internet connection was %s (%s), next one is %s (%s)", previousConnectionID.toAscii().data(), previousConnectionType.toAscii().data(), configuration.internetAPID.toAscii().data(), configuration.internetAPType.toAscii().data());
 			if(previousConnectionType == configuration.internetAPType && previousConnectionID == configuration.internetAPID && configuration.internetInterface() != configuration.INTERFACE_WLAN)
 				/** Nothing to do to the internet connection **/
-				/** In case of USB-Lan and Wifi-Inet we have to disconnect, change powersave & reconnect to prevent route disappearing problem **/
+				/** In case of USB-Lan and Wifi-Inet we have to disconnect & reconnect to prevent route disappearing problem **/
 				qDebug("** Internet connection is already good, skipping this step **");
 			else{
 				/** Disable current internet connection **/
@@ -397,13 +395,6 @@ void MobileHotspotGUI::startProcedure(){
 				if(ret != 0)
 					throw QString(tr("Error while disconnecting previous internet connection"));
 
-				/** USB-Lan Wifi-Inet **/
-				if(configuration.internetInterface() == configuration.INTERFACE_WLAN){
-					/** Change powersave if needed **/
-					if(configuration.disablePowerSaving)
-						APNHelper::setAPNPowerSave(configuration.internetAPID, GCONF_APN_POWER_NOECO);
-				}
-
 				/** Connect to the chosen APN **/
 				ret = HotspotHelper::enableInternetConnection(configuration);
 				if(ret != 0)
@@ -456,15 +447,9 @@ void MobileHotspotGUI::startProcedure(){
 				throw QString(tr("Error while preparing the Wifi interface"));
 		}
 
-		/** Stop dnsmasq - may fail, not fatal unless timeout **/
-		ret = HotspotHelper::stopDnsMasq(configuration);
-		if(ret == -2)
-			throw QString(tr("Error (timeout) while stopping the DHCP/DNS server"));
-		else if(ret != 0)
-			qDebug("WARNING : Could not stop dnsmasq (maybe it was not running - its fine)");
-
 		/** Start dnsmasq **/
-		ret = HotspotHelper::startDnsMasq(configuration, &dnsmasqProcess);
+		dnsmasqProcess = new QProcess();
+		ret = HotspotHelper::startDnsMasq(configuration, dnsmasqProcess);
 		if(ret != 0)
 			throw QString("Error while starting dnsmasq");
 
@@ -495,15 +480,15 @@ void MobileHotspotGUI::startProcedure(){
 	}
 
 	/** Enforcement 2G/3G **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
 		qDebug("Changing 2g/3g enforcement");
 		ret = 0;
-		if(configuration.enforcement2g3g == ENFORCE_2G && previousEnforcement != ENFORCEMENT_2G)
-			ret = DBUSHelper::setInternetEnforcement2G3G(ENFORCEMENT_2G);
-		else if(configuration.enforcement2g3g == ENFORCE_3G && previousEnforcement != ENFORCEMENT_3G)
-			ret = DBUSHelper::setInternetEnforcement2G3G(ENFORCEMENT_3G);
-		else if(previousEnforcement != ENFORCEMENT_NONE)
-			ret = DBUSHelper::setInternetEnforcement2G3G(ENFORCEMENT_NONE);
+		if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_2G && previousEnforcement != DBUS_2G3G_2G)
+			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_2G);
+		else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_3G && previousEnforcement != DBUS_2G3G_3G)
+			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_3G);
+		else if(configuration.enforcement2g3g == ENFORCEMENT_2G3G_DOUBLE && previousEnforcement != DBUS_2G3G_DOUBLE)
+			ret = DBUSHelper::setInternetEnforcement2G3G(DBUS_2G3G_DOUBLE);
 		if(ret != 0)
 			qDebug("WARNING : Cannot change 2g/3g enforcement");
 	}
@@ -557,10 +542,14 @@ void MobileHotspotGUI::stopProcedure(){
 	}
 
 	/** Stop dnsmasq **/
-	ret = HotspotHelper::stopDnsMasq(configuration);
-	if(ret != 0){
-		qDebug("Error while stopping dnsmasq");
-		success = false;
+	if(dnsmasqProcess != 0){
+		ret = HotspotHelper::stopDnsMasq(configuration, dnsmasqProcess);
+		if(ret != 0){
+			qDebug("Error while stopping dnsmasq");
+			success = false;
+		}
+		delete dnsmasqProcess;
+		dnsmasqProcess = 0;
 	}
 
 	/** USB vs Wifi **/
@@ -620,13 +609,6 @@ void MobileHotspotGUI::stopProcedure(){
 				success = false;
 			}
 
-			/** USB-Lan Wifi-Inet **/
-			if(configuration.internetInterface() == configuration.INTERFACE_WLAN){
-				/** Change powersave if needed **/
-				if(configuration.disablePowerSaving)
-					APNHelper::setAPNPowerSave(configuration.internetAPID, apnPowerSave);
-			}
-
 			if(previousConnectionID != ""){
 				/** Restore previous internet connection **/
 				qDebug("** Restoring previous internet connection **");
@@ -673,7 +655,7 @@ void MobileHotspotGUI::stopProcedure(){
 	}
 
 	/** Enforcement 2G/3G **/
-	if(configuration.internetEnabled && configuration.enforcement2g3g != IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
+	if(configuration.internetEnabled && configuration.enforcement2g3g != ENFORCEMENT_2G3G_IGNORE && configuration.internetInterface() == configuration.INTERFACE_GPRS){
 		qDebug("Restoring original 2g/3g enforcement");
 		ret = DBUSHelper::setInternetEnforcement2G3G(previousEnforcement);
 		if(ret != 0)
