@@ -30,6 +30,8 @@ private slots:
 	void disableAll();
 	void reset();
 	void macClicked();
+	void load();
+	void save();
 };
 
 #endif // PLUGINGUI_H
