@@ -14,6 +14,7 @@ enum UserAgent{
 class PluginConfiguration{
 
 public:
+	PluginConfiguration();
 	PluginConfiguration(MobileHotspotPluginHelper *helper);
 	~PluginConfiguration();
 	void save();
@@ -24,6 +25,10 @@ public:
 	QString ports;
 	UserAgent ua;
 	QString customUA;
+	bool defaultActions;
+	bool forward;
+	QString forwardIP;
+	int forwardPort;
 
 private:
 	MobileHotspotPluginHelper *helper; // Helper for this plugin
